==> uikit-3.13.10.jar: META-INF/resources/webjars/uikit/3.13.10/src/js/core/index.js <==
export { default as Accordion } from './accordion';
export { default as Alert } from './alert';
export { default as Cover } from './cover';
export { default as Drop, default as Dropdown } from './drop';
export { default as FormCustom } from './form-custom';
export { default as Grid } from './grid';
export { default as HeightMatch } from './height-match';
export { default as HeightViewport } from './height-viewport';
export { default as Icon } from './icon';
export { default as Img } from './img';
export { default as Leader } from './leader';
export { default as Margin } from './margin';
export { default as Modal } from './modal';
export { default as Nav } from './nav';
export { default as Navbar } from './navbar';
export { default as Offcanvas } from './offcanvas';
export { default as OverflowAuto } from './overflow-auto';
export { default as Responsive } from './responsive';
export { default as Scroll } from './scroll';
export { default as Scrollspy } from './scrollspy';
export { default as ScrollspyNav } from './scrollspy-nav';
export { default as Sticky } from './sticky';
export { default as Svg } from './svg';
export { default as Switcher } from './switcher';
export { default as Tab } from './tab';
export { default as Toggle } from './toggle';
export { default as Video } from './video';

// Icon components
export { Close } from './icon';
export { Spinner } from './icon';
export { Slidenav as SlidenavNext } from './icon';
export { Slidenav as SlidenavPrevious } from './icon';
export { Search as SearchIcon } from './icon';
export { IconComponent as Marker } from './icon';
export { IconComponent as NavbarToggleIcon } from './icon';
export { IconComponent as OverlayIcon } from './icon';
export { IconComponent as PaginationNext } from './icon';
export { IconComponent as PaginationPrevious } from './icon';
export { IconComponent as Totop } from './icon';

==> uikit-3.17.11.jar: META-INF/resources/webjars/uikit/3.17.11/src/js/core/index.js <==
export { default as Accordion } from './accordion';
export { default as Alert } from './alert';
export { default as Cover } from './cover';
export { default as Drop, default as Dropdown } from './drop';
export { default as Dropnav } from './dropnav';
export { default as FormCustom } from './form-custom';
export { default as Grid } from './grid';
export { default as HeightMatch } from './height-match';
export { default as HeightViewport } from './height-viewport';
export { default as Icon } from './icon';
export { default as Img } from './img';
export { default as Leader } from './leader';
export { default as Margin } from './margin';
export { default as Modal } from './modal';
export { default as Nav } from './nav';
export { default as Navbar } from './navbar';
export { default as Offcanvas } from './offcanvas';
export { default as OverflowAuto } from './overflow-auto';
export { default as Responsive } from './responsive';
export { default as Scroll } from './scroll';
export { default as Scrollspy } from './scrollspy';
export { default as ScrollspyNav } from './scrollspy-nav';
export { default as Sticky } from './sticky';
export { default as Svg } from './svg';
export { default as Switcher } from './switcher';
export { default as Tab } from './tab';
export { default as Toggle } from './toggle';
export { default as Video } from './video';

// Icon components
export {
    Close,
    IconComponent as DropParentIcon,
    Marker,
    NavParentIcon,
    IconComponent as NavbarParentIcon,
    NavbarToggleIcon,
    IconComponent as OverlayIcon,
    PaginationNext,
    PaginationPrevious,
    Search as SearchIcon,
    Slidenav as SlidenavNext,
    Slidenav as SlidenavPrevious,
    Spinner,
    Totop,
} from './icon';
